local dust_texture = Resources.load_texture("dust.png")

local function create_dust(direction)
    local artifact = Artifact.new()
    artifact:set_texture(dust_texture)
    artifact:set_facing(direction)

    local artifact_anim = artifact:animation()
    artifact_anim:load("dust.animation")
    artifact_anim:set_state("DEFAULT")
    artifact_anim:on_complete(function()
        artifact:erase()
    end)

    return artifact
end

---@param augment Augment
function augment_init(augment)
    local player = augment:owner()
    local component = player:create_component(Lifetime.Local)

    component.on_update_func = function()
        local forward_direction_input = Input.Pressed.Right
        local reversed_direction_input = Input.Pressed.Left

        if player:facing() == Direction.Left then
            local temp = forward_direction_input
            forward_direction_input = reversed_direction_input
            reversed_direction_input = temp
        end

        if player:team() == Team.Blue then
            local temp = forward_direction_input
            forward_direction_input = reversed_direction_input
            reversed_direction_input = temp
        end

        local has_forward = player:input_has(forward_direction_input)
        local has_reverse = player:input_has(reversed_direction_input)
        local holding_side_direction = (has_forward or has_reverse) and not (has_forward and has_reverse)

        if player:input_has(Input.Held.Shoot) and holding_side_direction then
            if has_reverse then
                local new_direction = player:facing_away()
                player:set_facing(new_direction)
            end

            local dust = create_dust(player:facing_away())
            dust:sprite():set_layer(1)
            player:field():spawn(dust, player:current_tile())
        end
    end

    augment.on_delete_func = function()
        component:eject()
    end
end
